# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKTransformPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkRigid3DPerspectiveTransformPython
else:
    import _itkRigid3DPerspectiveTransformPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkArray2DPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.itkVersorPython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkTransformBasePython
import itk.itkArrayPython
import itk.itkSymmetricSecondRankTensorPython
import itk.ITKCommonBasePython
import itk.itkOptimizerParametersPython
import itk.itkVariableLengthVectorPython
import itk.itkDiffusionTensor3DPython

def itkRigid3DPerspectiveTransformD_New():
    return itkRigid3DPerspectiveTransformD.New()

class itkRigid3DPerspectiveTransformD(itk.itkTransformBasePython.itkTransformD32):
    r"""Proxy of C++ itkRigid3DPerspectiveTransformD class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRigid3DPerspectiveTransformD_Pointer"""
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRigid3DPerspectiveTransformD_Pointer"""
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_Clone(self)

    def GetOffset(self):
        r"""GetOffset(self) -> itkVectorD3"""
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_GetOffset(self)

    def GetRotation(self):
        r"""GetRotation(self) -> itkVersorD"""
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_GetRotation(self)

    def SetOffset(self, offset):
        r"""
        SetOffset(self, offset)

        Parameters
        ----------
        offset: itkVectorD3 const &

        """
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_SetOffset(self, offset)

    def SetRotation(self, *args):
        r"""
        SetRotation(self, rotation)

        Parameters
        ----------
        rotation: itkVersorD const &

        SetRotation(self, axis, angle)

        Parameters
        ----------
        axis: itkVectorD3 const &
        angle: double

        """
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_SetRotation(self, *args)

    def SetFocalDistance(self, focalDistance):
        r"""
        SetFocalDistance(self, focalDistance)

        Parameters
        ----------
        focalDistance: double

        """
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_SetFocalDistance(self, focalDistance)

    def GetFocalDistance(self):
        r"""GetFocalDistance(self) -> double"""
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_GetFocalDistance(self)

    def TransformVector(self, *args):
        r"""
        TransformVector(self, arg0) -> itkVectorD2

        Parameters
        ----------
        arg0: itkVectorD3 const &

        TransformVector(self, arg0) -> vnl_vector_fixed< double,2 >

        Parameters
        ----------
        arg0: vnl_vector_fixed< double,3 > const &

        """
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_TransformVector(self, *args)

    def GetRotationMatrix(self):
        r"""GetRotationMatrix(self) -> itkMatrixD33"""
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_GetRotationMatrix(self)

    def ComputeMatrix(self):
        r"""ComputeMatrix(self)"""
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_ComputeMatrix(self)

    def GetFixedOffset(self):
        r"""GetFixedOffset(self) -> itkVectorD3"""
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_GetFixedOffset(self)

    def SetFixedOffset(self, _arg):
        r"""
        SetFixedOffset(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        """
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_SetFixedOffset(self, _arg)

    def SetCenterOfRotation(self, _arg):
        r"""
        SetCenterOfRotation(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        """
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_SetCenterOfRotation(self, _arg)

    def GetCenterOfRotation(self):
        r"""GetCenterOfRotation(self) -> itkPointD3"""
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_GetCenterOfRotation(self)
    __swig_destroy__ = _itkRigid3DPerspectiveTransformPython.delete_itkRigid3DPerspectiveTransformD

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRigid3DPerspectiveTransformD

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRigid3DPerspectiveTransformD

        Create a new object of the class itkRigid3DPerspectiveTransformD and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRigid3DPerspectiveTransformD.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRigid3DPerspectiveTransformD.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRigid3DPerspectiveTransformD.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRigid3DPerspectiveTransformD in _itkRigid3DPerspectiveTransformPython:
_itkRigid3DPerspectiveTransformPython.itkRigid3DPerspectiveTransformD_swigregister(itkRigid3DPerspectiveTransformD)

